use eyre::{Context, Result};
use handlebars::Handlebars;
use rust_embed::RustEmbed;
use tracing::info;

#[derive(RustEmbed)]
#[folder = "templates/"]
struct Templates;

pub fn handlebars(dev_mode: bool) -> Result<Handlebars<'static>> {
    let mut hbs = Handlebars::new();

    if dev_mode {
        info!("Reading templates from file system, as dev mode is enabled");

        hbs.set_dev_mode(true);
        hbs.register_templates_directory("", "templates/")
            .wrap_err("registering templates from directory")?;
    } else {
        hbs.register_embed_templates::<Templates>()
            .wrap_err("registering templates from embed")?;
    }

    Ok(hbs)
}
